pub fn scenario_content_id(scenario: &CharacterizationScenario) -> [u8; 32]Expand description
Stable 256-bit identity over the schema, id, input, and expected observation.
pub fn scenario_content_id(scenario: &CharacterizationScenario) -> [u8; 32]Stable 256-bit identity over the schema, id, input, and expected observation.